'use strict';

exports.__esModule = true;

var _reduxAdmin = require('redux-admin');

var _validate = require('validate.js');

var _utils = require('./utils.js');

var EMPTY_OBJ = {};

var DEFAULT_FIELDS = ['_id', 'createdAt', 'updatedAt'];

var getListFields = function getListFields(_ref) {
  var rtl = _ref.rtl,
      lang = _ref.lang;
  var jsonSchema = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var dashboardConfig = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var properties = jsonSchema.properties || EMPTY_OBJ;
  var fields = [];
  Object.keys(properties).forEach(function (itemKey) {
    var item = properties[itemKey];
    var meta = (0, _validate.getDeepObjectValue)(item, 'meta.0') || EMPTY_OBJ;
    if ((item.type === 'object' || item.type === Object) && meta === EMPTY_OBJ) {
      // in this case the meta can be found at the children as parentDashboard, this is a workaround;
      var metaFromInnerField = void 0;
      Object.keys(item.properties).forEach(function (itemKey) {
        if (!metaFromInnerField) {
          var innerField = item.properties[itemKey];
          metaFromInnerField = (0, _validate.getDeepObjectValue)(innerField, 'meta.0.parentDashboard');
        }
      });
      if (metaFromInnerField) {
        meta = { dashboard: metaFromInnerField };
      }
    }
    var dashboard = (0, _validate.getDeepObjectValue)(meta, 'dashboard') || EMPTY_OBJ;
    var dashboardList = (0, _validate.getDeepObjectValue)(meta, 'dashboard.list') || EMPTY_OBJ;
    var dashboardConfigDefaultFields = dashboardConfig.defaultFieldsToDisplay;
    if (dashboardConfigDefaultFields && DEFAULT_FIELDS.includes(itemKey) && !dashboardConfigDefaultFields.includes(itemKey)) {
      return null;
    }
    var type = item.type;

    if (item.format === 'date-time') type = Date;
    if (meta.ref) {
      type = Object;
    }
    if (dashboard.hide) return null;
    if (dashboardList.hide) return null;
    var fieldConfig = {
      key: itemKey,
      title: (0, _utils.getFieldName)({ target: 'list', lang: lang, itemKey: itemKey, dashboardList: dashboardList, dashboard: dashboard, dashboardConfig: dashboardConfig }),
      type: dashboardList.type || type,
      sorter: dashboardList.sorter === false ? false : dashboardList.sorter || true,
      width: dashboardList.width,
      labelKey: meta.displayKey,
      dateFormat: dashboardList.dateFormat
    };
    if (dashboardList.options) {
      fieldConfig.render = function (cal) {
        if (dashboardList.options) {
          var valueFromOptions = dashboardList.options.find(function (option) {
            return option.value === cal;
          });
          if (valueFromOptions) {
            var valueToDisplay = valueFromOptions.i18nLabels && valueFromOptions.i18nLabels[lang] || valueFromOptions.label;
            return valueToDisplay || cal;
          }
        }
        return cal;
      };
    }
    fields.push(_reduxAdmin.listHelpers.getListField(fieldConfig));
  });
  return fields;
};
exports.default = getListFields;
module.exports = exports['default'];